@@ -1,7 +1,10 @@
-// -*- mode:C++; tab-width:8; c-basic-offset:8; indent-tabs-mode:nil -*-
 
-/* Blackjack - game.cpp
- * Copyright (C) 2003 William Jon McCann <mccann@jhu.edu>
+// -*- mode:C++; tab-width:8; c-basic-offset:8; indent-tabs-mode:nil -*-
+/*
+ * Blackjack - game.cpp
+ *
+ * Copyright (C) 2003-2004 William Jon McCann <mccann@jhu.edu>
+ * Copyright © 2008 Christian Persch
  *
  * This game is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,28 +24,25 @@
 
 #include <config.h>
 
-#ifdef HAVE_ALLOCA_H
-#include <alloca.h>
-#endif
-
-#include <gnome.h>
-#include <sys/types.h>
-#include <string.h>
+#include <errno.h>
 #include <stdlib.h>
-#include <time.h>
-#include <dirent.h>
-#include <ctype.h>
+#include <string.h>
+#include <glib/gi18n.h>
+#include <glib/gstdio.h>
+
+#include <libgames-support/games-runtime.h>
 
 #include "blackjack.h"
 #include "events.h"
 #include "draw.h"
 #include "chips.h"
 #include "splash.h"
-
 #include "player.h"
 #include "hand.h"
 #include "game.h"
 
+#define RULES_GROUP "Blackjack Rules"
+
 #include <iostream>
 using namespace std;
 
@@ -64,28 +64,28 @@ gint             dealerSpeed;
 
 gint             numHands;
 
-gchar            *game_file = "";
+gchar            *game_file;
 gchar            *game_name;
 
-gboolean         allSettled = false;
-gboolean         game_is_done = false;
-gboolean         first_hand = true;
+gboolean         allSettled = FALSE;
+gboolean         game_is_done = FALSE;
+gboolean         first_hand = TRUE;
 
 GList *rules_list = NULL;
 
-BJGameRules::BJGameRules (bool hitSoft17, bool doubleAnyTotal, 
-                          bool double9, bool doubleSoft, 
-                          bool doubleAfterHit, bool doubleAfterSplit,
-                          bool resplit, bool resplitAces, 
-                          bool lateSurrender, int numDecks, int dealerSpeed)
-        : BJRules (hitSoft17, doubleAnyTotal, 
-                   double9, doubleSoft, 
-                   doubleAfterHit, doubleAfterSplit,
-                   resplit, resplitAces, 
-                   lateSurrender)
+BJGameRules::BJGameRules (bool lhitSoft17, bool ldoubleAnyTotal, 
+                          bool ldouble9, bool ldoubleSoft, 
+                          bool ldoubleAfterHit, bool ldoubleAfterSplit,
+                          bool lresplit, bool lresplitAces, 
+                          bool llateSurrender, int lnumDecks, int ldealerSpeed)
+        : BJRules (lhitSoft17, ldoubleAnyTotal, 
+                   ldouble9, ldoubleSoft, 
+                   ldoubleAfterHit, ldoubleAfterSplit,
+                   lresplit, lresplitAces, 
+                   llateSurrender)
 {
-        this->numDecks = numDecks;
-        this->dealerSpeed = dealerSpeed;
+        numDecks = lnumDecks;
+        dealerSpeed = ldealerSpeed;
 }
 
 int
@@ -128,31 +128,45 @@ bj_game_file_to_name (const gchar* file)
         return p;
 }
 
-int
-bj_is_ruleset (const gchar *file_name)
+/* copied from gnome-util.c */
+static const char *
+extension_pointer (const char * path)
 {
-        return (!strcmp (g_extension_pointer (file_name), "rules"));
+        const char * s, * t;
+        
+        g_return_val_if_fail (path != NULL, NULL);
+
+        /* get the dot in the last element of the path */
+        t = strrchr (path, G_DIR_SEPARATOR);
+        if (t != NULL)
+                s = strrchr (t, '.');
+        else
+                s = strrchr (path, '.');
+        
+        if (s == NULL)
+                return path + strlen (path); /* There is no extension. */
+        else {
+                ++s;      /* pass the . */
+                return s;
+        }
 }
 
+
 void
-bj_game_find_rules (gchar *variation)
+bj_game_find_rules (const gchar *variation)
 {
         GDir *dir;
-        gchar *dname;
         G_CONST_RETURN gchar* file_name;
         gint n_games = 0;
+        const char *rulesdir;
 
-        dname = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_DATADIR,
-                                           BJ_RULES_DIR, FALSE, NULL);
-
-        dir = g_dir_open (dname, 0, NULL);
+        rulesdir = games_runtime_get_directory (GAMES_RUNTIME_GAME_GAMES_DIRECTORY);
+        dir = g_dir_open (rulesdir, 0, NULL);
         if (dir == NULL)
                 return;
   
-        g_free (dname);
-
         while ((file_name = g_dir_read_name (dir)) != NULL) {
-                if (! bj_is_ruleset (file_name))
+                if (!g_str_has_suffix (file_name, ".rules"))
                         continue;
 
                 n_games++;
@@ -176,7 +190,7 @@ bj_game_get_rules_name ()
         return game_name;
 }
 
-char *
+const char *
 bj_game_get_rules_file ()
 {
         return game_file;
@@ -198,11 +212,11 @@ void
 bj_game_set_active (gboolean value)
 {
         if (value) {
-                game_is_done = false;
-                first_hand = false;
+                game_is_done = FALSE;
+                first_hand = FALSE;
         }
         else
-                game_is_done = true;
+                game_is_done = TRUE;
 
 }
 
@@ -212,12 +226,10 @@ bj_get_deal_delay ()
         return (bj_get_quick_deal ()) ? 1 : dealerSpeed;
 }
 
-
 BJGameRules *
-bj_game_read_rules (gchar *filename)
+bj_game_read_rules (const char *filename)
 {
         BJGameRules *ruleset;
-        gboolean used_default;
         gboolean hitSoft17,
                 doubleAnyTotal,
                 double9,
@@ -227,75 +239,89 @@ bj_game_read_rules (gchar *filename)
                 resplit,
                 resplitAces,
                 lateSurrender;
-        gint numDecks,
-                dealerSpeed;
-  
-        gnome_config_pop_prefix ();
-        gnome_config_push_prefix (g_strdup_printf ("=%s=", filename));
+        gint lnumDecks,
+                ldealerSpeed;
+        GKeyFile *key_file;
 
-        numDecks = gnome_config_get_int_with_default 
-                ("General/Number Of Decks=6",
-                 &used_default);
-        hitSoft17 = gnome_config_get_bool_with_default 
-                ("House Rules/Dealer Hits Soft 17=false",
-                 &used_default);
-        doubleAnyTotal = gnome_config_get_bool_with_default 
-                ("House Rules/Double Down Any Total=true",
-                 &used_default);
-        double9 = gnome_config_get_bool_with_default 
-                ("House Rules/Double Down 9=true",
-                 &used_default);
-        doubleSoft = gnome_config_get_bool_with_default
-                ("House Rules/Double Down Soft=true",
-                 &used_default);
-        doubleAfterHit = gnome_config_get_bool_with_default
-                ("House Rules/Double Down After Hit=false",
-                 &used_default);
-        doubleAfterSplit = gnome_config_get_bool_with_default
-                ("House Rules/Double Down After Split=true",
-                 &used_default);
-        resplit = gnome_config_get_bool_with_default
-                ("House Rules/Resplit Allowed=true",
-                 &used_default);
-        resplitAces = gnome_config_get_bool_with_default
-                ("House Rules/Resplit Aces Allowed=true",
-                 &used_default);
-        lateSurrender = gnome_config_get_bool_with_default
-                ("House Rules/Surrender Allowed=true",
-                 &used_default);
-        dealerSpeed = gnome_config_get_int_with_default
-                ("House Rules/Dealer Speed=500",
-                 &used_default);
+        lnumDecks = 6;
+        hitSoft17 = FALSE;
+        doubleAnyTotal = TRUE;
+        double9 = TRUE;
+        doubleSoft = TRUE;
+        doubleAfterHit = FALSE;
+        doubleAfterSplit = TRUE;
+        resplit = TRUE;
+        resplitAces = TRUE;
+        lateSurrender = TRUE;
+        ldealerSpeed = 500;
+
+        key_file = g_key_file_new ();
+        if (g_key_file_load_from_file (key_file, filename, GKeyFileFlags(0), NULL) &&
+            g_key_file_has_group (key_file, RULES_GROUP)) {
+                GError *error = NULL;
+                int value;
+
+#define CHECK_AND_ASSIGN(variable) \
+                if (error) {\
+                        g_printerr ("Failed to read value from rules file: %s\n", error->message);\
+                        g_clear_error(&error);\
+                } else {\
+                        variable = value;\
+                }
+
+                value = g_key_file_get_integer (key_file, RULES_GROUP, "NumberOfDecks", &error);
+                CHECK_AND_ASSIGN (lnumDecks);
+                value = g_key_file_get_integer (key_file, RULES_GROUP, "DealerSpeed", &error);
+                CHECK_AND_ASSIGN (ldealerSpeed);
+                value = g_key_file_get_boolean (key_file, RULES_GROUP, "DealerHitsSoft17", &error);
+                CHECK_AND_ASSIGN (hitSoft17);
+                value = g_key_file_get_boolean (key_file, RULES_GROUP, "DoubleDownAnyTotal", &error);
+                CHECK_AND_ASSIGN (doubleAnyTotal);
+                value = g_key_file_get_boolean (key_file, RULES_GROUP, "DoubleDown9", &error);
+                CHECK_AND_ASSIGN (double9);
+                value = g_key_file_get_boolean (key_file, RULES_GROUP, "DoubleDownSoft", &error);
+                CHECK_AND_ASSIGN (doubleSoft);
+                value = g_key_file_get_boolean (key_file, RULES_GROUP, "DoubleDownAfterHit", &error);
+                CHECK_AND_ASSIGN (doubleAfterHit);
+                value = g_key_file_get_boolean (key_file, RULES_GROUP, "DoubleDownAfterSplit", &error);
+                CHECK_AND_ASSIGN (doubleAfterSplit);
+                value = g_key_file_get_boolean (key_file, RULES_GROUP, "ResplitAllowed", &error);
+                CHECK_AND_ASSIGN (resplit);
+                value = g_key_file_get_boolean (key_file, RULES_GROUP, "ResplitAcesAllowed", &error);
+                CHECK_AND_ASSIGN (resplitAces);
+                value = g_key_file_get_boolean (key_file, RULES_GROUP, "SurrenderAllowed", &error);
+                CHECK_AND_ASSIGN (lateSurrender);
+
+#undef CHECK_AND_ASSIGN
+        }
+
+        g_key_file_free (key_file);
 
         // Compute basic strategy.
         ruleset = new BJGameRules (hitSoft17, doubleAnyTotal, 
                                    double9, doubleSoft, 
                                    doubleAfterHit, doubleAfterSplit,
                                    resplit, resplitAces, 
-                                   lateSurrender, numDecks, dealerSpeed);
+                                   lateSurrender, lnumDecks, ldealerSpeed);
   
         return ruleset;
 }
 
 
 BJGameRules *
-bj_game_find_and_read_rules (gchar *filename)
+bj_game_find_and_read_rules (const gchar *filename)
 {
         gchar *installed_filename;
-        gchar *relative;
         BJGameRules *ruleset = NULL;
+        const char *rulesdir;
 
-        relative = g_build_filename (BJ_RULES_DIR, filename, NULL);
-        installed_filename = gnome_program_locate_file (NULL, 
-                                                        GNOME_FILE_DOMAIN_APP_DATADIR,
-                                                        relative,
-                                                        FALSE, NULL);
+        rulesdir = games_runtime_get_directory (GAMES_RUNTIME_GAME_GAMES_DIRECTORY);
+        installed_filename = g_build_filename (rulesdir, filename, NULL);
 
         if (g_file_test (installed_filename, G_FILE_TEST_EXISTS))
                 ruleset = bj_game_read_rules (installed_filename);
 
         g_free (installed_filename);
-        g_free (relative);
 
         return ruleset;
 }
@@ -303,41 +329,31 @@ bj_game_find_and_read_rules (gchar *filename)
 static gchar *
 bj_game_get_config_dir (void)
 {
+#define GNOME_DOT_GNOME            ".gnome2/"
         gchar *conf_dir = NULL;
 
-        conf_dir = g_build_filename (gnome_user_dir_get (),
+        conf_dir = g_build_filename (g_get_home_dir (),
+                                     GNOME_DOT_GNOME,
                                      "blackjack.d",
                                      NULL);
+
+        if (g_mkdir_with_parents (conf_dir, 0700) < 0 && errno != EEXIST)
+                g_warning ("Failed to create config directory \"%s\": %s\n", conf_dir, g_strerror (errno));
+
         return conf_dir;
 }
 
 static void
-bj_game_ensure_config_dir_exists (const char *dir)
-{
-        if (g_file_test (dir, G_FILE_TEST_IS_DIR) == FALSE) {
-                if (g_file_test (dir, G_FILE_TEST_EXISTS) == TRUE) {
-                        // FIXME: use a dialog
-                        cerr << dir << " exists, please move it out of the way." << endl;
-                }
-                if (mkdir (dir, 488) != 0)
-                        cerr << "Failed to create directory " << dir << endl;
-        }
-}
-
-static void
-bj_game_eval_installed_file (gchar *file)
+bj_game_eval_installed_file (const gchar *file)
 {
+        const char *rulesdir;
         char *installed_filename;
-        char *relative;
 
         if (g_file_test (file, G_FILE_TEST_EXISTS))
                 return;
   
-        relative = g_build_filename (BJ_RULES_DIR, file, NULL);
-        installed_filename = gnome_program_locate_file (NULL, 
-                                                        GNOME_FILE_DOMAIN_APP_DATADIR,
-                                                        relative,
-                                                        FALSE, NULL);
+        rulesdir = games_runtime_get_directory (GAMES_RUNTIME_GAME_GAMES_DIRECTORY);
+        installed_filename = g_build_filename (rulesdir, file, NULL);
 
         if (g_file_test (installed_filename, G_FILE_TEST_EXISTS)) {
                 rules = bj_game_read_rules (installed_filename);
@@ -353,13 +369,12 @@ bj_game_eval_installed_file (gchar *file)
                 gchar *cache_filename = g_strdup_printf ("%s%s", file, ".dat");
 
                 char *config_dir = bj_game_get_config_dir ();
-                bj_game_ensure_config_dir_exists (config_dir);
                 installed_filename = g_build_filename (config_dir, cache_filename, NULL);
                 g_free (config_dir);
                         
-                gboolean use_cache = false;
+                gboolean use_cache = FALSE;
                 if (g_file_test (installed_filename, G_FILE_TEST_EXISTS))
-                        use_cache = true;
+                        use_cache = TRUE;
 
                 if (! use_cache)
                         splash_new ();
@@ -379,7 +394,7 @@ bj_game_eval_installed_file (gchar *file)
                 gchar *message = g_strdup_printf ("%s\n %s", _("Blackjack can't load the requested file"),
                                                   installed_filename);
                 gchar *message2 = _("Please check your Blackjack installation");
-                GtkWidget *w = gtk_message_dialog_new_with_markup (GTK_WINDOW (app),
+                GtkWidget *w = gtk_message_dialog_new_with_markup (GTK_WINDOW (toplevel_window),
                                                                    GTK_DIALOG_DESTROY_WITH_PARENT,
                                                                    GTK_MESSAGE_ERROR,
                                                                    GTK_BUTTONS_CLOSE,
@@ -393,7 +408,6 @@ bj_game_eval_installed_file (gchar *file)
                 exit (1);
         }
         g_free (installed_filename);
-        g_free (relative);
 }
 
 void 
@@ -401,31 +415,36 @@ bj_game_cancel ()
 {
         bj_hand_cancel ();
         bj_game_set_active (FALSE);
+        bj_press_data_free ();
+        bj_chip_stack_press_data_free ();
 }
 
 void
-bj_game_new (gchar* file, guint *seedp )
+bj_game_new (const gchar* file, guint *seedp )
 {
         gint min_w, min_h;
 
         bj_game_cancel ();
 
-        first_hand = true;
+        first_hand = TRUE;
 
         bj_show_balance (bj_get_balance ());
 
-        if (file && strcmp (file, game_file)) {
-                game_file = file;
+        if (file && (!game_file || strcmp (file, game_file) != 0)) {
+                char *old_game_file = game_file;
+
+                game_file = g_strdup (file);
+                g_free (old_game_file);
                 
-                bj_game_eval_installed_file (file);
-                game_name = bj_game_file_to_name (file);
+                bj_game_eval_installed_file (game_file);
+                game_name = bj_game_file_to_name (game_file);
                 
                 if (option_dialog) {
                         gtk_widget_destroy (option_dialog);
                         option_dialog = NULL;
                 }
 
-                bj_set_game_variation (file);
+                bj_set_game_variation (game_file);
         }
 
         if (seedp)
@@ -459,7 +478,8 @@ bj_game_new (gchar* file, guint *seedp )
 
         bj_clear_table ();
 
-        bj_make_window_title (game_name, seed);
+        bj_make_window_title (game_name);
+        bj_update_control_menu ();
 }
 
 void
@@ -501,6 +521,7 @@ bj_clear_table ()
         dealer->reset ();
         dealerProbabilities->reset ();
 
-        first_hand = true;
+        first_hand = TRUE;
+        gtk_widget_queue_draw (playing_area);
 }
 
